@@ -1,9 +1,7 @@
-from mlxtk.inout import (expval, fixed_ns, g1, g2, natpop,
-                         one_body_operator_matrix)
+from mlxtk.inout import expval, fixed_ns, g1, g2, natpop, one_body_operator_matrix
 from mlxtk.inout.fixed_ns import read_fixed_ns_ascii, write_fixed_ns_hdf5
 from mlxtk.inout.gpop import read_gpop
 from mlxtk.inout.natpop import read_natpop
 from mlxtk.inout.output import read_output
-from mlxtk.inout.psi import (read_first_frame, read_psi_ascii, read_spfs,
-                             write_psi_ascii)
+from mlxtk.inout.psi import read_first_frame, read_psi_ascii, read_spfs, write_psi_ascii
 from mlxtk.inout.spectrum import read_spectrum
