@@ -13,8 +13,8 @@ LOGGER = get_logger(__name__)
 
 
 def read_eigenbasis_ascii(
-    path: Union[str,
-                Path]) -> Tuple[numpy.ndarray, numpy.ndarray, numpy.ndarray]:
+    path: Union[str, Path]
+) -> Tuple[numpy.ndarray, numpy.ndarray, numpy.ndarray]:
     path = make_path(path)
     path_energies = path / "eigenenergies"
     path_vectors = path / "eigenvectors"
@@ -37,14 +37,15 @@ def read_eigenbasis_ascii(
     return energies, tape, psi
 
 
-def add_eigenbasis_to_hdf5(fptr: Union[h5py.File,
-                                       h5py.Group], energies: numpy.ndarray,
-                           tape: numpy.ndarray, psi: numpy.ndarray):
+def add_eigenbasis_to_hdf5(
+    fptr: Union[h5py.File, h5py.Group],
+    energies: numpy.ndarray,
+    tape: numpy.ndarray,
+    psi: numpy.ndarray,
+):
     grp = fptr.create_group("energies")
-    grp.create_dataset("real", energies.shape,
-                       dtype=numpy.float64)[:] = energies.real
-    grp.create_dataset("imag", energies.shape,
-                       dtype=numpy.float64)[:] = energies.imag
+    grp.create_dataset("real", energies.shape, dtype=numpy.float64)[:] = energies.real
+    grp.create_dataset("imag", energies.shape, dtype=numpy.float64)[:] = energies.imag
     fptr.create_dataset("tape", tape.shape, dtype=numpy.int64)[:] = tape
     grp = fptr.create_group("vectors")
     grp.create_dataset("real", psi.shape, dtype=numpy.float64)[:, :] = psi.real
