@@ -1,6 +1,7 @@
 from typing import Any, Dict, Iterable, List, Union
 
 from mlxtk.dvr import DVRSpecification
+from mlxtk.log import get_logger
 from QDTK.Operatorb import OCoef as Coeff
 from QDTK.Operatorb import Operatorb as Operator
 from QDTK.Operatorb import OTerm as Term
@@ -19,6 +20,7 @@ class MBOperatorSpecification:
         self.grids = grids
         self.coefficients = coefficients
         self.terms = terms
+        self.logger = get_logger(__name__ + ".MBOperatorSpecification")
 
         if isinstance(table, str):
             self.table = [table]
@@ -33,8 +35,9 @@ class MBOperatorSpecification:
             output.append("\t\t{}: {}".format(i, grid))
         output.append("\tCoefficients:")
         for i, coefficient in enumerate(self.coefficients):
-            output.append("\t\t{}: {} = {}".format(
-                i, coefficient, self.coefficients[coefficient]))
+            output.append(
+                "\t\t{}: {} = {}".format(i, coefficient, self.coefficients[coefficient])
+            )
         output.append("\tTerms:")
         for i, term in enumerate(self.terms):
             output.append("\t\t{}: {}".format(i, term))
@@ -44,8 +47,9 @@ class MBOperatorSpecification:
         return "\n".join(output)
 
     def __add__(self, other):
-        cpy = MBOperatorSpecification(self.dofs, self.grids, self.coefficients,
-                                      self.terms, self.table)
+        cpy = MBOperatorSpecification(
+            self.dofs, self.grids, self.coefficients, self.terms, self.table
+        )
         cpy.__iadd__(other)
         return cpy
 
@@ -55,9 +59,13 @@ class MBOperatorSpecification:
     def __iadd__(self, other):
         if not isinstance(other, MBOperatorSpecification):
             raise RuntimeError(
-                ("other object must be of type "
-                 "MBOperatorSpecification as well (not {})".format(
-                     type(other).__name__)))
+                (
+                    "other object must be of type "
+                    "MBOperatorSpecification as well (not {})".format(
+                        type(other).__name__
+                    )
+                )
+            )
 
         if self.dofs != other.dofs:
             raise ValueError("dofs differ")
@@ -65,11 +73,13 @@ class MBOperatorSpecification:
         if self.grids != other.grids:
             raise ValueError("grids differ")
 
-        if not set(self.coefficients.keys()).isdisjoint(
-                set(other.coefficients.keys())):
-            raise ValueError("coefficient names are not unique\n" +
-                             str(self.coefficients) + "\n" +
-                             str(other.coefficients))
+        if not set(self.coefficients.keys()).isdisjoint(set(other.coefficients.keys())):
+            raise ValueError(
+                "coefficient names are not unique\n"
+                + str(self.coefficients)
+                + "\n"
+                + str(other.coefficients)
+            )
 
         if not set(self.terms.keys()).isdisjoint(set(other.terms.keys())):
             raise ValueError("term names are not unique")
@@ -86,8 +96,9 @@ class MBOperatorSpecification:
         return self
 
     def __mul__(self, other):
-        cpy = MBOperatorSpecification(self.dofs, self.grids, self.coefficients,
-                                      self.terms, self.table)
+        cpy = MBOperatorSpecification(
+            self.dofs, self.grids, self.coefficients, self.terms, self.table
+        )
         cpy.__imul__(other)
         return cpy
 
@@ -100,8 +111,9 @@ class MBOperatorSpecification:
         return self
 
     def __truediv__(self, other):
-        cpy = MBOperatorSpecification(self.dofs, self.grids, self.coefficients,
-                                      self.terms, self.table)
+        cpy = MBOperatorSpecification(
+            self.dofs, self.grids, self.coefficients, self.terms, self.table
+        )
         cpy.__itruediv__(other)
         return cpy
 
@@ -122,7 +134,8 @@ class MBOperatorSpecification:
 
         if term_kwargs.get("type", "diag") != "diag":
             raise NotImplementedError(
-                "Only diagonal time-dependent terms are supported by QDTK")
+                "Only diagonal time-dependent terms are supported by QDTK"
+            )
         term_kwargs["type"] = "diag"
 
         term_kwargs["tf_label"] = term["td_name"]
@@ -136,8 +149,7 @@ class MBOperatorSpecification:
 
     def get_operator(self) -> Operator:
         op = Operator()
-        op.define_dofs_and_grids(self.dofs,
-                                 [grid.get() for grid in self.grids])
+        op.define_dofs_and_grids(self.dofs, [grid.get() for grid in self.grids])
 
         for coeff in self.coefficients:
             op.addLabel(coeff, Coeff(self.coefficients[coeff]))
