@@ -14,28 +14,38 @@ def create_frame_worker(args):
     create_frame(*args)
 
 
-def create_frame(index: int, time: float, x1: numpy.ndarray, x2: numpy.ndarray,
-                 values: numpy.ndarray, valmin: float, valmax: float,
-                 file_name_fmt: str, args: argparse.Namespace):
+def create_frame(
+    index: int,
+    time: float,
+    x1: numpy.ndarray,
+    x2: numpy.ndarray,
+    values: numpy.ndarray,
+    valmin: float,
+    valmax: float,
+    file_name_fmt: str,
+    args: argparse.Namespace,
+):
     unitsys = mlxtk.units.get_default_unit_system()
 
     X2, X1 = numpy.meshgrid(x2, x1)
 
     fig, ax = plt.subplots(1, 1)
-    ax.set_title("$t=" + "{:8.2f}".format(time) + r"\," +
-                 str(unitsys.get_time_unit()) + "$")
+    ax.set_title(
+        "$t=" + "{:8.2f}".format(time) + r"\," + str(unitsys.get_time_unit()) + "$"
+    )
     ax.set_xlabel(unitsys.get_length_unit().format_label("x_1"))
     ax.set_ylabel(unitsys.get_length_unit().format_label("x_2"))
-    ax.set_title(r"$\left|g_1(x_1,x_2,t)\right|,\quad " + "t=" +
-                 "{:8.2f}".format(time) + r"\," +
-                 str(unitsys.get_time_unit()) + "$")
-    mesh = ax.pcolormesh(X1,
-                         X2,
-                         values,
-                         rasterized=True,
-                         cmap="gnuplot",
-                         vmin=valmin,
-                         vmax=valmax)
+    ax.set_title(
+        r"$\left|g_1(x_1,x_2,t)\right|,\quad "
+        + "t="
+        + "{:8.2f}".format(time)
+        + r"\,"
+        + str(unitsys.get_time_unit())
+        + "$"
+    )
+    mesh = ax.pcolormesh(
+        X1, X2, values, rasterized=True, cmap="gnuplot", vmin=valmin, vmax=valmax
+    )
     fig.colorbar(mesh)
     mlxtk.plot.apply_2d_args(ax, fig, args)
     mlxtk.plot.save(fig, file_name_fmt.format(index))
@@ -44,17 +54,21 @@ def create_frame(index: int, time: float, x1: numpy.ndarray, x2: numpy.ndarray,
 
 def main():
     parser = argparse.ArgumentParser()
-    parser.add_argument("-i",
-                        "--input",
-                        dest="input_",
-                        type=Path,
-                        default="g1.h5",
-                        help="path to the g1 file")
-    parser.add_argument("-o",
-                        "--output",
-                        type=Path,
-                        default=Path("g1.mp4"),
-                        help="path for the video file")
+    parser.add_argument(
+        "-i",
+        "--input",
+        dest="input_",
+        type=Path,
+        default="g1.h5",
+        help="path to the g1 file",
+    )
+    parser.add_argument(
+        "-o",
+        "--output",
+        type=Path,
+        default=Path("g1.mp4"),
+        help="path for the video file",
+    )
     mlxtk.plot.add_argparse_2d_args(parser)
     args = parser.parse_args()
 
@@ -76,14 +90,13 @@ def main():
         ]
         with mlxtk.cwd.WorkingDir(tmpdir):
             with multiprocessing.Pool() as pool:
-                for _ in tqdm(pool.imap_unordered(create_frame_worker,
-                                                  parameters),
-                              total=len(times)):
+                for _ in tqdm(
+                    pool.imap_unordered(create_frame_worker, parameters),
+                    total=len(times),
+                ):
                     pass
 
-        files = [
-            Path(tmpdir) / file_name_fmt.format(i) for i, _ in enumerate(times)
-        ]
+        files = [Path(tmpdir) / file_name_fmt.format(i) for i, _ in enumerate(times)]
         mlxtk.tools.video.create_slideshow(files, args.output, 30.0)
 
 
