@@ -16,6 +16,7 @@ def main():
     parser.add_argument("dmat2", type=Path)
     parser.add_argument("-o", "--output", default="g2.h5", type=Path)
     parser.add_argument("--diff", action="store_true")
+    parser.add_argument("--normalize", action="store_true")
     args = parser.parse_args()
 
     LOGGER.info("read dmat")
@@ -24,8 +25,10 @@ def main():
     data_dmat2 = dmat2.read_dmat2_gridrep_hdf5(args.dmat2, "dmat2_gridrep")
 
     if args.diff:
-        data = compute_g2_diff(data_dmat, data_dmat2)
+        data = compute_g2_diff(data_dmat, data_dmat2, normalize=args.normalize)
     else:
+        if args.normalize:
+            parser.error("The --normalize flag requires the --dif flag to be set.")
         data = compute_g2(data_dmat, data_dmat2)
 
     with h5py.File(args.output, "w") as fptr:
