@@ -8,15 +8,10 @@ from mlxtk.plot import create_gpop_model
 
 def main():
     parser = argparse.ArgumentParser()
-    parser.add_argument("path",
-                        nargs="?",
-                        default="gpop.h5",
-                        help="path to the gpop file")
-    parser.add_argument("-d",
-                        "--dof",
-                        type=int,
-                        default=1,
-                        help="degree of freedom")
+    parser.add_argument(
+        "path", nargs="?", default="gpop.h5", help="path to the gpop file"
+    )
+    parser.add_argument("-d", "--dof", type=int, default=1, help="degree of freedom")
     args = parser.parse_args()
 
     time, grid, density = read_gpop(args.path, dof=args.dof)
