@@ -21,17 +21,18 @@ def main():
     num_frames = len(times)
     num_coeffs = int(binom(N + m - 1, N))
 
-    only_spfs = numpy.zeros(shape=(num_frames, frames.shape[1] - num_coeffs),
-                            dtype=frames.dtype)
+    only_spfs = numpy.zeros(
+        shape=(num_frames, frames.shape[1] - num_coeffs), dtype=frames.dtype
+    )
     for i, _ in enumerate(times):
         only_spfs[i] = frames[i][num_coeffs:]
 
     only_spfs = numpy.reshape(only_spfs, (num_frames, m, n))
 
     with h5py.File(args.output, "w") as fptr:
-        fptr.create_dataset("spfs",
-                            shape=only_spfs.shape,
-                            dtype=only_spfs.dtype)[:, :, :] = only_spfs
+        fptr.create_dataset("spfs", shape=only_spfs.shape, dtype=only_spfs.dtype)[
+            :, :, :
+        ] = only_spfs
 
 
 if __name__ == "__main__":
