@@ -5,24 +5,26 @@ import matplotlib.pyplot as plt
 
 from mlxtk import units
 from mlxtk.inout.natpop import read_natpop
-from mlxtk.plot import (add_argparse_2d_args, add_argparse_save_arg,
-                        apply_2d_args, handle_saving)
+from mlxtk.plot import (
+    add_argparse_2d_args,
+    add_argparse_save_arg,
+    apply_2d_args,
+    handle_saving,
+)
 from mlxtk.plot.natpop import plot_natpop
 
 
 def main():
     parser = argparse.ArgumentParser()
-    parser.add_argument("path",
-                        nargs="?",
-                        type=Path,
-                        default=Path("propagate.h5/natpop"),
-                        help="path to the natpop file")
+    parser.add_argument(
+        "path",
+        nargs="?",
+        type=Path,
+        default=Path("propagate.h5/natpop"),
+        help="path to the natpop file",
+    )
     parser.add_argument("-n", "--node", type=int, default=1, help="node")
-    parser.add_argument("-d",
-                        "--dof",
-                        type=int,
-                        default=1,
-                        help="degree of freedom")
+    parser.add_argument("-d", "--dof", type=int, default=1, help="degree of freedom")
     add_argparse_2d_args(parser)
     add_argparse_save_arg(parser)
     args = parser.parse_args()
@@ -33,8 +35,7 @@ def main():
     plot_natpop(ax, time, natpop)
 
     try:
-        ax.set_xlabel(
-            units.get_default_unit_system().get_time_unit().format_label("t"))
+        ax.set_xlabel(units.get_default_unit_system().get_time_unit().format_label("t"))
     except units.MissingUnitError:
         ax.set_xlabel("$t$")
 
