@@ -14,9 +14,5 @@ def cmd_dry_run(self: SimulationBase, args: argparse.Namespace):
     with WorkingDir(self.working_dir):
         with LockFile(Path("run.lock")):
             run_doit(
-                self.tasks_dry_run,
-                [
-                    "--backend=json",
-                    "--db-file=doit.json",
-                ],
+                self.tasks_dry_run, ["--backend=json", "--db-file=doit.json",],
             )
