@@ -9,21 +9,22 @@ def check_propagation_status(self: SimulationBase, propagation: str) -> float:
     work_dir = self.working_dir / ("." + propagation)  # sim/.propagate/
     final_dir = self.working_dir / propagation  # sim/propagate/
     result_file = final_dir / "propagate.h5"  # sim/propagate/propagate.h5
-    pickle_file = self.working_dir / (propagation + ".prop_pickle"
-                                      )  # sim/propagate.prop_pickle
+    pickle_file = self.working_dir / (
+        propagation + ".prop_pickle"
+    )  # sim/propagate.prop_pickle
     output_file = work_dir / "output"  # sim/.propagate/output
 
     if not work_dir.exists():
         if result_file.exists():
-            return 1.
+            return 1.0
         else:
-            return 0.
+            return 0.0
 
     if not pickle_file.exists():
-        return 0.
+        return 0.0
 
     if not output_file.exists():
-        return 0.
+        return 0.0
 
     with open(pickle_file, "rb") as fptr:
         tfinal = pickle.load(fptr)[3]["tfinal"]
@@ -36,4 +37,4 @@ def check_propagation_status(self: SimulationBase, propagation: str) -> float:
 def cmd_propagation_status(self: SimulationBase, args: argparse.Namespace):
     self.logger.info("check progress of propagation: %s", args.name)
     progress = check_propagation_status(self, args.name)
-    self.logger.info("total progress: %6.2f%%", progress * 100.)
+    self.logger.info("total progress: %6.2f%%", progress * 100.0)
