@@ -10,8 +10,9 @@ def cmd_qdel(self: SimulationBase, args: argparse.Namespace):
     del args
 
     if not self.working_dir.exists():
-        self.logger.warning("working dir %s does not exist, do nothing",
-                            self.working_dir)
+        self.logger.warning(
+            "working dir %s does not exist, do nothing", self.working_dir
+        )
         return
     with WorkingDir(self.working_dir):
         if Path("sge_stop").exists():
