@@ -12,8 +12,9 @@ def cmd_qsub(self: SimulationBase, args: argparse.Namespace):
     call_dir = Path.cwd().absolute()
     script_path = Path(sys.argv[0]).absolute()
     with WorkingDir(self.working_dir):
-        sge.submit(" ".join([sys.executable,
-                             str(script_path), "run"]),
-                   args,
-                   sge_dir=call_dir,
-                   job_name=self.name)
+        sge.submit(
+            " ".join([sys.executable, str(script_path), "run"]),
+            args,
+            sge_dir=call_dir,
+            job_name=self.name,
+        )
