@@ -9,10 +9,5 @@ def cmd_task_info(self: SimulationBase, args: argparse.Namespace):
     with WorkingDir(self.working_dir):
         run_doit(
             self.tasks_run,
-            [
-                "info",
-                "--backend=json",
-                "--db-file=doit.json",
-                args.name,
-            ],
+            ["info", "--backend=json", "--db-file=doit.json", args.name,],
         )
