@@ -6,8 +6,7 @@ from mlxtk.simulation import Simulation
 from mlxtk.simulation_set.base import SimulationSetBase
 
 
-def run_simulation(
-        simulation: Simulation) -> List[Callable[[], Dict[str, Any]]]:
+def run_simulation(simulation: Simulation) -> List[Callable[[], Dict[str, Any]]]:
     """Create a task for running the given simulation.
 
     Args:
@@ -16,6 +15,7 @@ def run_simulation(
     Returns:
         list: list with a single doit task description for simulation run
     """
+
     def task_run_simulation():
         @DoitAction
         def action_run_simulation(targets: List[str]):
@@ -42,9 +42,5 @@ def cmd_run(self: SimulationSetBase, args: argparse.Namespace):
         tasks += run_simulation(simulation)
     run_doit(
         tasks,
-        [
-            "--process=" + str(args.jobs),
-            "--backend=sqlite3",
-            "--db-file=:memory:",
-        ],
+        ["--process=" + str(args.jobs), "--backend=sqlite3", "--db-file=:memory:",],
     )
