@@ -47,11 +47,9 @@ class CreateMBOperator(Task):
                         for key in self.specification.terms
                     }
                     if "value" in obj[4][term]:
-                        obj[4][term]["value"] = inaccurate_hash(
-                            obj[4][term]["value"])
+                        obj[4][term]["value"] = inaccurate_hash(obj[4][term]["value"])
                 else:
-                    obj[4][term] = inaccurate_hash(
-                        self.specification.terms[term])
+                    obj[4][term] = inaccurate_hash(self.specification.terms[term])
 
             with open(targets[0], "wb") as fp:
                 pickle.dump(obj, fp, protocol=3)
@@ -87,7 +85,7 @@ class CreateMBOperator(Task):
 
         return {
             "name": "mb_operator:{}:remove".format(self.name),
-            "actions": [action_remove_operator]
+            "actions": [action_remove_operator],
         }
 
     def get_tasks_run(self) -> List[Callable[[], Dict[str, Any]]]:
