@@ -12,9 +12,9 @@ from mlxtk.util import make_path
 LOGGER = get_logger(__name__)
 
 
-def create_slideshow(files: List[Union[Path, str]],
-                     output_file: Union[Path, str],
-                     duration: float = 30.0):
+def create_slideshow(
+    files: List[Union[Path, str]], output_file: Union[Path, str], duration: float = 30.0
+):
     if not len(files):
         LOGGER.error("No image files specified! Nothing to do.")
         return
@@ -27,14 +27,17 @@ def create_slideshow(files: List[Union[Path, str]],
             max_number_len = len(str(len(files)))
 
             for i, file in enumerate(files):
-                os.symlink(file, ("{:0" + str(max_number_len) + "d}{}").format(
-                    i, file.suffix))
+                os.symlink(
+                    file, ("{:0" + str(max_number_len) + "d}{}").format(i, file.suffix)
+                )
 
             cmd = [
-                "ffmpeg", "-r",
-                str(float(len(files)) / duration), "-i",
+                "ffmpeg",
+                "-r",
+                str(float(len(files)) / duration),
+                "-i",
                 "%0" + str(max_number_len) + "d" + files[0].suffix,
-                "output.mp4"
+                "output.mp4",
             ]
             subprocess.run(cmd)
 
